@@ -5,8 +5,8 @@
 //! Hello world!
 
 // Globals are declared outside all other scopes.
-static LANGUAGE: &str = "Rust";
-const THRESHOLD: i32 = 10;
+pub static LANGUAGE: &str = "Rust";
+pub const THRESHOLD: i32 = 10;
 
 pub fn array_length(array: &[u8]) -> usize {
     array.len()
